package
Version:
v0.0.0-...-784945a
Opens a new window with list of versions in this module.
Published: Feb 11, 2026
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func Ternary[T any](b bool, t, f T) T
func (m *Map[K, V]) Delete(key K) (value V, ok bool)
func (m *Map[K, V]) Range(f func(key K, value V) bool)
func (m *Map[K, V]) Store(key K, value V) (ok bool)
func (m *Map[K, V]) Wait()
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.